<?php

namespace Drupal\field_suggestion;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\FieldTypePluginManagerInterface;
use Drupal\service\FieldTypePluginManagerTrait;
use Drupal\service\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines a class to build a listing of field suggestion type entities.
 *
 * @see \Drupal\field_suggestion\Entity\FieldSuggestionType
 */
class FieldSuggestionTypeListBuilder extends ConfigEntityListBuilder {

  use FieldTypePluginManagerTrait;
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public static function createInstance(
    ContainerInterface $container,
    EntityTypeInterface $entity_type
  ): static {
    return parent::createInstance($container, $entity_type)
      ->addFieldTypePluginManager($container)
      ->addStringTranslation();
  }

  /**
   * {@inheritdoc}
   */
  public function buildHeader(): array {
    return [
      'id' => $this->t('Machine name'),
      'label' => $this->t('Title'),
      'description' => $this->t('Description'),
    ] + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity): array {
    $definition = $this->fieldTypePluginManager()->getDefinition($entity->id());

    return [
      'id' => $entity->id(),
      'label' => $entity->label(),
      'description' => $definition['description'],
    ] + parent::buildRow($entity);
  }

}
